#!/bin/sh
#
# sources : http://belnet.dl.sourceforge.net/sourceforge/kipi/libkipi-0.1.6.tar.bz2
#
# maintainer : gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft='libkipi'
softversion='0.1.6'
packageversion='54.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.tgz
rm -rf $dest

#-----------------build directories and copy the build script

mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

       |-----handy-ruler-----------------------------------------------------|
libkipi: libkipi (KDE Image Plugin Interface)
libkipi:
libkipi: Kipi (KDE Image Plugin Interface) is an effort to develop a common
libkipi: plugin structure for Digikam, KimDaBa, Showimg and Gwenview. Its aim 
libkipi: is to share image plugins among graphic applications. Kipi is based
libkipi: on the old digiKam plugins implementation and is maintened by
libkipi: digiKam team.
libkipi:
libkipi:
libkipi:
libkipi:
EODESC

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --disable-debug

make -j2
make install DESTDIR=$dest

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

#-------------------Prepare the documentation

rm -rf $dest/usr/share/doc
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL NEWS PACKAGING README RELEASE.rev TODO $dest/usr/doc/$soft-$softversion

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5